---
title: <span class="badge object-type-scalar"></span> IcelandicKrona
---
# <span class="badge object-type-scalar"></span> IcelandicKrona

Currency: Icelandic Króna (kr)

## Definition

```python
# Currency: Icelandic Króna (kr)
IcelandicKrona: typing.Literal["currencyISK"] = "currencyISK"
```
